==> webkitgtk-2.6.5.tar.xz: webkitgtk-2.6.5/Source/WebCore/Modules/mediastream/CapabilityRange.h <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 *
 */

#ifndef CapabilityRange_h
#define CapabilityRange_h

#if ENABLE(MEDIA_STREAM)

#include "MediaStreamSourceCapabilities.h"
#include "ScriptWrappable.h"
#include <bindings/ScriptValue.h>
#include <interpreter/CallFrame.h>
#include <wtf/RefCounted.h>

namespace WebCore {

class CapabilityRange : public RefCounted<CapabilityRange>, public ScriptWrappable {
public:
    virtual ~CapabilityRange() { }

    static RefPtr<CapabilityRange> create(const MediaStreamSourceCapabilityRange&);

    Deprecated::ScriptValue min(JSC::ExecState*) const;
    Deprecated::ScriptValue max(JSC::ExecState*) const;
    bool supported() const { return m_rangeInfo.supported(); }

private:
    CapabilityRange(const MediaStreamSourceCapabilityRange&);
    
    MediaStreamSourceCapabilityRange m_rangeInfo;
};

} // namespace WebCore

#endif // CapabilityRange_h

#endif

==> webkitgtk-2.10.2.tar.xz: webkitgtk-2.10.2/Source/WebCore/Modules/mediastream/CapabilityRange.h <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 *
 */

#ifndef CapabilityRange_h
#define CapabilityRange_h

#if ENABLE(MEDIA_STREAM)

#include "RealtimeMediaSourceCapabilities.h"
#include "ScriptWrappable.h"
#include <bindings/ScriptValue.h>
#include <interpreter/CallFrame.h>
#include <wtf/RefCounted.h>

namespace WebCore {

class CapabilityRange : public RefCounted<CapabilityRange>, public ScriptWrappable {
public:
    virtual ~CapabilityRange() { }

    static Ref<CapabilityRange> create(const RealtimeMediaSourceCapabilityRange&);

    Deprecated::ScriptValue min(JSC::ExecState*) const;
    Deprecated::ScriptValue max(JSC::ExecState*) const;
    bool supported() const { return m_rangeInfo.supported(); }

private:
    CapabilityRange(const RealtimeMediaSourceCapabilityRange&);
    
    RealtimeMediaSourceCapabilityRange m_rangeInfo;
};

} // namespace WebCore

#endif // CapabilityRange_h

#endif
